#
# db2_secured::controls::authenticate_federated_users_at_the_instance_level
#
# @summary The `fed_noauth` parameter determines whether federated authentication will be bypassed at the instance.
# It is recommended that this parameter be set to `no`.
# 
# Rationale:
# 
# Setting `fed_noauth` to `no` will ensure that authentication is checked at the instance level. This will prevent any federated authentication from bypassing the client and the server.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::authenticate_federated_users_at_the_instance_level: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::authenticate_federated_users_at_the_instance_level::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `authenticate_federated_users_at_the_instance_level` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.10
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::authenticate_federated_users_at_the_instance_level {
  $elements = $title.split('/')
  $instance = $elements[0]

  db2_secured_setup { "authenticate_federated_users_at_the_instance_level on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_instance[${instance}]fed_noauth":
    allow_create   => true,
    allow_redefine => true,
    value          => 'NO',
  }
}
