#
# db2_secured::controls::database_manager_configuration_parameter_fed_noauth
#
# @summary The `FED_NOAUTH` database manager configuration parameter determines whether federated authentication will be bypassed at the instance.
# If this parameter is set to `YES`, the `AUTHENTICATION` parameter is set to `SERVER` or `SERVER_ENCRYPT` and the `FEDERATED` parameter is set to `YES`, then authentication at the instance is bypassed and is instead assumed to be performed at the data source.
# 
# It is recommended to set this parameter to `NO`.
# 
# Rationale:
# 
# Setting `FED_NOAUTH` to `NO` will ensure that authentication is not bypassed for any users that are connecting to the instance.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::database_manager_configuration_parameter_fed_noauth: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::database_manager_configuration_parameter_fed_noauth::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `database_manager_configuration_parameter_fed_noauth` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 5.6
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::database_manager_configuration_parameter_fed_noauth {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "database_manager_configuration_parameter_fed_noauth on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_instance[${instance}]fed_noauth":
    allow_create   => true,
    allow_redefine => true,
    value          => 'NO',
  }
}
