#
# db2_secured::controls::database_manager_configuration_parameter_trust_clntauth
#
# @summary Thge `TRUST_CLNTAUTH` database manager configuration parameter is only active when the authentication parameter is set to `CLIENT` which is not a recommended setting as discussed in the authentication parameter section.
# If the parameter is set to `CLIENT`, the user ID and password are not needed, but if they are provided, authentication will occur at the client. If the parameter is set to `SERVER`, the user ID and password are needed and will be authenticated at the server.
# 
# The recommended value for this parameter is `SERVER`.
# 
# Rationale:
# 
# If the server trusts the client to authenticate the connecting user, a malicious user can connect to the database as any user including a database administrator by simply creating that user on the client system.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::database_manager_configuration_parameter_trust_clntauth: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::database_manager_configuration_parameter_trust_clntauth::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `database_manager_configuration_parameter_trust_clntauth` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 5.5
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::database_manager_configuration_parameter_trust_clntauth {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "database_manager_configuration_parameter_trust_clntauth on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_instance[${instance}]srvcon_auth/3":
    allow_create   => true,
    allow_redefine => true,
    value          => 'SERVER_ENCRYPT',
  }
}
