#
# db2_secured::controls::disable_database_discovery
#
# @summary The `discover_db` parameter specifies if the database will respond to a discovery request from a client.
# It is recommended that this parameter be set to `DISABLE`.
# 
# Rationale:
# 
# Setting the database discovery to disabled can hide a database with sensitive data.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::disable_database_discovery: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::disable_database_discovery::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `disable_database_discovery` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.16
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 4.1.4
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::disable_database_discovery {
  db2_secured_setup { "disable_database_discovery on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_database[${title}]discover_db":
    allow_create   => true,
    allow_redefine => true,
    value          => 'DISABLE',
  }
}
