#
# db2_secured::controls::establish_retention_set_size_for_backups
#
# @summary The `num_db_backups` parameter specifies the number of backups to retain for a database before marking the oldest backup as deleted.
# It is recommended that this parameter be set to at least 12.
# 
# Rationale:
# 
# Retain multiple copies of the database backup to ensure that the database can recover from an unexpected failure. This parameter should not be set to 0. Multiple backups should be kept to ensure that all logs and transactions can be used for auditing.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::establish_retention_set_size_for_backups: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::establish_retention_set_size_for_backups::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `establish_retention_set_size_for_backups` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.21
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 4.1.10
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::establish_retention_set_size_for_backups (
  Integer[12] $preferred_value = db2_secured::lookup_setting('preferred_value', 12),
) {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "establish_retention_set_size_for_backups on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_database[${instance}/${database}]num_db_backups":
    allow_create   => true,
    allow_redefine => true,
    value          => $preferred_value,
  }
}
