#
# db2_secured::controls::remove_unused_schemas
#
# @summary A schema is a logical grouping of database objects.
# It is recommended that unused schemas be removed from the database.
# 
# Rationale:
# 
# Unused schemas can be left unmonitored and may be subjected to abuse and therefore should be removed.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::remove_unused_schemas: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::remove_unused_schemas::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `remove_unused_schemas` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 4.5.2
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::remove_unused_schemas (
  Array $list        = db2_secured::lookup_setting('list', []),
) {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  $system_schemas = [
    'SYSIBM',
    'SYSCAT',
    'SYSFUN',
    'SYSSTAT',
    'SYSPROC',
    'SYSIBMADM',
    'SYSIBMINTERNAL',
    'SYSIBMTS',
    'SYSPUBLIC',
    'NULLID',
    'SQLJ',
    'SYSTOOLS',
  ]

  db2_secured_setup { "remove_unused_schemas on ${title}":
    ensure => 'present',
  }

  if  $facts['db2_schemas'] {
    $schemas_to_remove = $facts['db2_schemas'].keys.filter |$schema| {
      $parts = $schema.split('/')
      $schema_instance = $parts[0]
      $schema_database = $parts[1]
      $schema_name     = $parts[2]
      $value = ($schema_instance == $instance) and ($schema_database == $database) and !($schema_name in $list) and !($schema_name in $system_schemas)
      $value
    }
    db2_schema { $schemas_to_remove:
      ensure => 'absent',
    }
  } else {
    warning "Skipping this control until 'db2_schemas' fact is filled"
  }
}
