#
# db2_secured::controls::require_instance_name_for_discovery_requests
#
# @summary The `discover` parameter determines what kind of discovery requests, if any, the DB2 server will fulfill.
# It is recommended that the DB2 server only fulfill requests from clients that know the given instance name (`discover` parameter value of known).
# 
# Rationale:
# 
# Discovery capabilities may be used by a malicious entity to derive the names of and target DB2 instances. In this configuration, the client has to specify a known instance name to be able to detect the instance.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::require_instance_name_for_discovery_requests: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::require_instance_name_for_discovery_requests::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `require_instance_name_for_discovery_requests` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.8
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 3.1.6
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::require_instance_name_for_discovery_requests {
  $elements = $title.split('/')
  $instance = $elements[0]

  db2_secured_setup { "require_instance_name_for_discovery_requests on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_instance[${instance}]discover":
    allow_create   => true,
    allow_redefine => true,
    value          => 'KNOWN',
  }
}
