#
# db2_secured::controls::restrict_access_to_tablespaces
#
# @summary A tablespace is where the data is physically stored.
# It is recommended that tablespace usage be restricted to authorized users.
# 
# Rationale:
# 
# Grant the `USE` of tablespace privilege to only authorized users. Restrict the privilege from `PUBLIC`, where applicable, as a malicious user can cause a denial of service at the tablespace level by overloading it with corrupted data.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::restrict_access_to_tablespaces: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::restrict_access_to_tablespaces::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `restrict_access_to_tablespaces` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 6.24
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 4.5.1
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::restrict_access_to_tablespaces (
  Array $exclude = db2_secured::lookup_setting('exclude', []),
) {
  db2_secured_setup { "restrict_access_to_tablespaces on ${title}":
    ensure => 'present',
  }

  if  $facts['db2_tablespaces'] {
    $tablespaces_to_secure = db2_config::tablespaces_on_database($title) - $exclude

    $tablespaces_to_secure.each |$tablespace| {
      db2_exec { "${title}/restrict_access_to_tablespaces on ${tablespace}":
        statement => "revoke use of tablespace ${tablespace} from public",
        onlyif    => "select grantee, tbspace from sysibm.systbspaceauth where grantee = 'PUBLIC' and tbspace = '${tablespace}'",
      }
    }
  } else {
    warning "Skipping this control until 'db2_tablespaces' fact is filled"
  }
}
