#
# db2_secured::controls::secure_db2_runtime_library
#
# @summary A DB2 software installation will place all executables under the default <DB2PATH>\sqllib directory.
# This directory needs to be secured so it grants only the necessary access to authorized users and administrators.
# 
# Rationale:
# 
# The DB2 runtime is comprised of files that are executed as part of the DB2 service. If these resources are not secured, an attacker may alter them to execute arbitrary code.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::secure_db2_runtime_library: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::secure_db2_runtime_library::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `secure_db2_runtime_library` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 2.1
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 3.3.1
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::secure_db2_runtime_library {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "secure_db2_runtime_library on ${title}":
    ensure => 'present',
  }

  # lint:ignore:recurse_file
  range('0', '9').each |$no| {
    file { "/home/${instance}/NODE000${no}/sqldbdir]":
      mode    => '0755',
      recurse => true,
      require => Db2_secured_setup["secure_db2_runtime_library on ${title}"],
    }
  }
  # lint:endignore:recurse_file
}
