#
# db2_secured::controls::secure_permissions_for_the_log_mirror_location
#
# @summary The `mirrorlogpath` parameter specifies the type of media and the location used to store the mirror copy of the logs.
# It is recommended that the directory used for the mirror copy of the logs be set to full access for DB2 administrator accounts and read and execute only for all other accounts.
# 
# Rationale:
# 
# A mirror log path should not be empty and it should be a valid path. The mirror log path stores a second copy of the active log files. Access to the directory pointed to by that path should be restricted through permissions to help ensure that the confidentiality, integrity, and availability of the mirror logs are protected.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::secure_permissions_for_the_log_mirror_location: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::secure_permissions_for_the_log_mirror_location::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `secure_permissions_for_the_log_mirror_location` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.20
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 4.1.8
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::secure_permissions_for_the_log_mirror_location (
  Optional[Stdlib::Absolutepath] $preferred_value = undef,
) {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  if  $facts['db2_instances'] {
    $home     = $facts['db2_instances'][$instance]['dftdbpath']

    if $preferred_value == undef {
      $requested_value = db2_secured::lookup_setting('preferred_value', "${home}/archives/mirror/")
    } else {
      $requested_value = $preferred_value
    }

    db2_secured_setup { "secure_permissions_for_the_log_mirror_location on ${title}":
      ensure => 'present',
    }

    -> db2_secured::internal::archive_directory { "${title}/mirrorlogpath":
      path      => $requested_value,
      indicator => '',
    }
  } else {
    warning "Skipping this control until 'db2_instances' fact is filled"
  }
}
